@@ -30,7 +30,6 @@ schema = {
             "properties": {
                 "address": {"type": "string", "propertyOrder": 3},
                 "mask": {"type": "integer", "propertyOrder": 4},
-                "gateway": {"type": "string", "propertyOrder": 5},
             },
         },
         "ipv4_address": {
@@ -51,9 +50,11 @@ schema = {
                         },
                         "mask": {"minimum": 8, "maxmium": 32, "default": 24},
                         "gateway": {
+                            "type": "string",
                             "title": "ipv4 gateway",
                             "description": "optional ipv4 gateway",
                             "maxLength": 16,
+                            "propertyOrder": 5,
                         },
                     },
                 },
@@ -79,9 +80,11 @@ schema = {
                         },
                         "mask": {"minimum": 4, "maxmium": 128, "default": 64},
                         "gateway": {
+                            "type": "string",
                             "title": "ipv6 gateway",
                             "description": "optional ipv6 gateway",
                             "maxLength": 45,
+                            "propertyOrder": 5,
                         },
                     },
                 },
@@ -100,9 +103,9 @@ schema = {
                 },
             ],
         },
-        "interface_settings": {
+        "base_interface_settings": {
             "type": "object",
-            "title": "Interface settings",
+            "title": "Base Interface settings",
             "additionalProperties": True,
             "required": ["name", "type"],
             "properties": {
@@ -120,6 +123,19 @@ schema = {
                     "minimum": 68,
                     "propertyOrder": 2,
                 },
+                "disabled": {
+                    "type": "boolean",
+                    "description": "disable this interface without deleting its configuration",
+                    "default": False,
+                    "format": "checkbox",
+                    "propertyOrder": 6,
+                },
+            },
+        },
+        "interface_settings": {
+            "type": "object",
+            "title": "Interface settings",
+            "properties": {
                 "mac": {
                     "type": "string",
                     "title": "MAC address",
@@ -136,13 +152,6 @@ schema = {
                     "format": "checkbox",
                     "propertyOrder": 5,
                 },
-                "disabled": {
-                    "type": "boolean",
-                    "description": "disable this interface without deleting its configuration",
-                    "default": False,
-                    "format": "checkbox",
-                    "propertyOrder": 6,
-                },
                 "addresses": {
                     "type": "array",
                     "title": "Addresses",
@@ -172,6 +181,7 @@ schema = {
                         }
                     }
                 },
+                {"$ref": "#/definitions/base_interface_settings"},
                 {"$ref": "#/definitions/interface_settings"},
             ],
         },
@@ -199,6 +209,7 @@ schema = {
                         },
                     }
                 },
+                {"$ref": "#/definitions/base_interface_settings"},
                 {"$ref": "#/definitions/interface_settings"},
             ],
         },
@@ -229,11 +240,12 @@ schema = {
                             "items": {
                                 "title": "bridged interface",
                                 "type": "string",
-                                "$ref": "#/definitions/interface_settings/properties/name",
+                                "$ref": "#/definitions/base_interface_settings/properties/name",
                             },
                         },
                     }
                 },
+                {"$ref": "#/definitions/base_interface_settings"},
                 {"$ref": "#/definitions/interface_settings"},
             ],
         },
@@ -346,6 +358,10 @@ schema = {
                     "propertyOrder": 20,
                     "oneOf": [
                         {"$ref": "#/definitions/encryption_none"},
+                        {"$ref": "#/definitions/encryption_wpa3_personal"},
+                        {"$ref": "#/definitions/encryption_wpa3_enterprise_ap"},
+                        {"$ref": "#/definitions/encryption_wpa3_personal_mixed"},
+                        {"$ref": "#/definitions/encryption_wpa3_enterprise_ap_mixed"},
                         {"$ref": "#/definitions/encryption_wpa_personal"},
                         {"$ref": "#/definitions/encryption_wpa_enterprise_ap"},
                         {"$ref": "#/definitions/encryption_wps"},
@@ -363,6 +379,10 @@ schema = {
                     "propertyOrder": 20,
                     "oneOf": [
                         {"$ref": "#/definitions/encryption_none"},
+                        {"$ref": "#/definitions/encryption_wpa3_personal"},
+                        {"$ref": "#/definitions/encryption_wpa3_enterprise_sta"},
+                        {"$ref": "#/definitions/encryption_wpa3_personal_mixed"},
+                        {"$ref": "#/definitions/encryption_wpa3_enterprise_sta_mixed"},
                         {"$ref": "#/definitions/encryption_wpa_personal"},
                         {"$ref": "#/definitions/encryption_wpa_enterprise_sta"},
                         {"$ref": "#/definitions/encryption_wep"},
@@ -431,11 +451,97 @@ schema = {
                 }
             }
         },
+        "encryption_cipher_ccmp_required": {
+            "required": ["cipher"],
+            "properties": {
+                "cipher": {
+                    "type": "string",
+                    "enum": ["ccmp"],
+                    "options": {"enum_titles": ["Force CCMP (AES)"]},
+                    "readOnly": True,
+                    "propertyOrder": 3,
+                }
+            },
+        },
+        "encryption_mfp_property": {
+            "properties": {
+                "ieee80211w": {
+                    "type": "string",
+                    "title": "management frame protection",
+                    "enum": ["0", "1", "2"],
+                    "options": {"enum_titles": ["disabled", "optional", "required"]},
+                    "propertyOrder": 4,
+                }
+            }
+        },
+        "encryption_mfp_property_required": {
+            "required": ["ieee80211w"],
+            "properties": {
+                "ieee80211w": {
+                    "type": "string",
+                    "title": "management frame protection",
+                    "enum": ["2"],
+                    "readOnly": True,
+                    "options": {"enum_titles": ["required"]},
+                    "propertyOrder": 4,
+                }
+            },
+        },
+        "encryption_mfp_property_optional": {
+            "required": ["ieee80211w"],
+            "properties": {
+                "ieee80211w": {
+                    "type": "string",
+                    "title": "management frame protection",
+                    "enum": ["1"],
+                    "readOnly": True,
+                    "options": {"enum_titles": ["optional", "required"]},
+                    "propertyOrder": 4,
+                }
+            },
+        },
+        "encryption_wpa3_personal": {
+            "title": "WPA3 Personal",
+            "allOf": [
+                {"$ref": "#/definitions/encryption_base_settings"},
+                {"$ref": "#/definitions/encryption_cipher_ccmp_required"},
+                {"$ref": "#/definitions/encryption_mfp_property_required"},
+                {
+                    "properties": {
+                        "protocol": {
+                            "enum": ["wpa3_personal"],
+                            "options": {"enum_titles": ["WPA3 Personal"]},
+                        },
+                        "key": {"minLength": 8},
+                    }
+                },
+            ],
+        },
+        "encryption_wpa3_personal_mixed": {
+            "title": "WPA3/WPA2 Personal Mixed Mode",
+            "allOf": [
+                {"$ref": "#/definitions/encryption_base_settings"},
+                {"$ref": "#/definitions/encryption_cipher_ccmp_required"},
+                {"$ref": "#/definitions/encryption_mfp_property_optional"},
+                {
+                    "properties": {
+                        "protocol": {
+                            "enum": ["wpa2_personal_mixed"],
+                            "options": {
+                                "enum_titles": ["WPA3/WPA2 Personal Mixed Mode"]
+                            },
+                        },
+                        "key": {"minLength": 8},
+                    }
+                },
+            ],
+        },
         "encryption_wpa_personal": {
             "title": "WPA2/WPA Personal",
             "allOf": [
                 {"$ref": "#/definitions/encryption_base_settings"},
                 {"$ref": "#/definitions/encryption_cipher_property"},
+                {"$ref": "#/definitions/encryption_mfp_property"},
                 {
                     "properties": {
                         "protocol": {
@@ -447,7 +553,7 @@ schema = {
                             "options": {
                                 "enum_titles": [
                                     "WPA2 Personal",
-                                    "WPA Personal Mixed Mode",
+                                    "WPA2/WPA Personal Mixed Mode",
                                     "WPA Personal",
                                 ]
                             },
@@ -457,6 +563,166 @@ schema = {
                 },
             ],
         },
+        "encryption_wpa_enterprise_ap_base_settings": {
+            "required": ["server"],
+            "properties": {
+                "server": {
+                    "type": "string",
+                    "minLength": 3,
+                    "title": "radius server",
+                    "propertyOrder": 4,
+                },
+                "key": {"title": "shared secret", "minLength": 4, "propertyOrder": 5},
+                "port": {
+                    "type": "integer",
+                    "title": "radius port",
+                    "default": 1812,
+                    "propertyOrder": 6,
+                },
+                "acct_server": {
+                    "type": "string",
+                    "title": "accounting server",
+                    "propertyOrder": 7,
+                },
+                "acct_server_port": {
+                    "type": "integer",
+                    "title": "accounting port",
+                    "default": 1813,
+                    "propertyOrder": 8,
+                },
+            },
+        },
+        "encryption_wpa_enterprise_sta_base_settings": {
+            "properties": {
+                "eap_type": {
+                    "title": "EAP protocol",
+                    "type": "string",
+                    "enum": ["tls", "ttls", "peap"],
+                    "options": {"enum_titles": ["EAP-TLS", "EAP-TTLS", "EAP-PEAP"]},
+                    "propertyOrder": 4,
+                },
+                "auth": {
+                    "title": "authentication",
+                    "type": "string",
+                    "enum": [
+                        "PAP",
+                        "CHAP",
+                        "MSCHAP",
+                        "MSCHAPV2",
+                        "EAP-GTC",
+                        "EAP-MD5",
+                        "EAP-MSCHAPV2",
+                        "EAP-TLS",
+                    ],
+                    "options": {
+                        "enum_titles": [
+                            "PAP",
+                            "CHAP",
+                            "MSCHAP",
+                            "MSCHAPv2",
+                            "EAP-GTC",
+                            "EAP-MD5",
+                            "EAP-MSCHAPv2",
+                            "EAP-TLS",
+                        ]
+                    },
+                    "default": "MSCHAPV2",
+                    "description": (
+                        "Defines the phase 2 (inner) authentication method,"
+                        "only applicable if EAP protocol is EAP-PEAP or EAP-TTLS."
+                    ),
+                    "propertyOrder": 5,
+                },
+                "identity": {"type": "string", "propertyOrder": 6},
+                "password": {"type": "string", "propertyOrder": 7},
+                "ca_cert": {
+                    "type": "string",
+                    "title": "CA certificate (path)",
+                    "propertyOrder": 8,
+                },
+                "client_cert": {
+                    "type": "string",
+                    "title": "client certificate (path)",
+                    "propertyOrder": 9,
+                },
+                "priv_key": {
+                    "type": "string",
+                    "title": "private key (path)",
+                    "propertyOrder": 10,
+                },
+                "priv_key_pwd": {
+                    "type": "string",
+                    "title": "private key password",
+                    "propertyOrder": 11,
+                },
+            },
+        },
+        "encryption_wpa3_enterprise_base_settings": {
+            "properties": {
+                "protocol": {
+                    "type": "string",
+                    "title": "encryption protocol",
+                    "enum": ["wpa3_enterprise"],
+                    "options": {"enum_titles": ["WPA3 Enterprise"]},
+                    "propertyOrder": 1,
+                }
+            }
+        },
+        "encryption_wpa3_enterprise_mixed_base_settings": {
+            "properties": {
+                "protocol": {
+                    "type": "string",
+                    "title": "encryption protocol",
+                    "enum": ["wpa2_enterprise_mixed"],
+                    "options": {"enum_titles": ["WPA3/WPA2 Enterprise Mixed Mode"]},
+                    "propertyOrder": 1,
+                }
+            }
+        },
+        "encryption_wpa3_enterprise_ap": {
+            "title": "WPA3 Enterprise (access point)",
+            "allOf": [
+                {"$ref": "#/definitions/encryption_base_settings"},
+                {"$ref": "#/definitions/encryption_cipher_ccmp_required"},
+                {"$ref": "#/definitions/encryption_mfp_property_required"},
+                {"$ref": "#/definitions/encryption_wpa3_enterprise_base_settings"},
+                {"$ref": "#/definitions/encryption_wpa_enterprise_ap_base_settings"},
+            ],
+        },
+        "encryption_wpa3_enterprise_ap_mixed": {
+            "title": "WPA3/WPA2 Enterprise (access point) Mixed Mode",
+            "allOf": [
+                {"$ref": "#/definitions/encryption_base_settings"},
+                {"$ref": "#/definitions/encryption_cipher_ccmp_required"},
+                {"$ref": "#/definitions/encryption_mfp_property_optional"},
+                {
+                    "$ref": "#/definitions/encryption_wpa3_enterprise_mixed_base_settings"
+                },
+                {"$ref": "#/definitions/encryption_wpa_enterprise_ap_base_settings"},
+            ],
+        },
+        "encryption_wpa3_enterprise_sta": {
+            "title": "WPA3 Enterprise (client)",
+            "additionalProperties": True,
+            "allOf": [
+                {"$ref": "#/definitions/encryption_cipher_ccmp_required"},
+                {"$ref": "#/definitions/encryption_mfp_property_required"},
+                {"$ref": "#/definitions/encryption_wpa3_enterprise_base_settings"},
+                {"$ref": "#/definitions/encryption_wpa_enterprise_sta_base_settings"},
+            ],
+        },
+        "encryption_wpa3_enterprise_sta_mixed": {
+            "title": "WPA3/WPA2 Enterprise (client)",
+            "additionalProperties": True,
+            "allOf": [
+                {"$ref": "#/definitions/encryption_cipher_ccmp_required"},
+                {"$ref": "#/definitions/encryption_mfp_property_optional"},
+                {
+                    "$ref": "#/definitions/encryption_wpa3_enterprise_mixed_base_settings"
+                },
+                {"$ref": "#/definitions/encryption_wpa_enterprise_sta_base_settings"},
+            ],
+        },
         "encryption_wpa_enterprise_base_settings": {
             "properties": {
                 "protocol": {
@@ -470,7 +736,7 @@ schema = {
                     "options": {
                         "enum_titles": [
                             "WPA2 Enterprise",
-                            "WPA Enterprise Mixed Mode",
+                            "WPA2/WPA Enterprise Mixed Mode",
                             "WPA Enterprise",
                         ]
                     },
@@ -483,40 +749,9 @@ schema = {
             "allOf": [
                 {"$ref": "#/definitions/encryption_base_settings"},
                 {"$ref": "#/definitions/encryption_cipher_property"},
+                {"$ref": "#/definitions/encryption_mfp_property"},
                 {"$ref": "#/definitions/encryption_wpa_enterprise_base_settings"},
-                {
-                    "required": ["server"],
-                    "properties": {
-                        "server": {
-                            "type": "string",
-                            "minLength": 3,
-                            "title": "radius server",
-                            "propertyOrder": 4,
-                        },
-                        "key": {
-                            "title": "shared secret",
-                            "minLength": 4,
-                            "propertyOrder": 5,
-                        },
-                        "port": {
-                            "type": "integer",
-                            "title": "radius port",
-                            "default": 1812,
-                            "propertyOrder": 6,
-                        },
-                        "acct_server": {
-                            "type": "string",
-                            "title": "accounting server",
-                            "propertyOrder": 7,
-                        },
-                        "acct_server_port": {
-                            "type": "integer",
-                            "title": "accounting port",
-                            "default": 1813,
-                            "propertyOrder": 8,
-                        },
-                    },
-                },
+                {"$ref": "#/definitions/encryption_wpa_enterprise_ap_base_settings"},
             ],
         },
         "encryption_wpa_enterprise_sta": {
@@ -524,40 +759,9 @@ schema = {
             "additionalProperties": True,
             "allOf": [
                 {"$ref": "#/definitions/encryption_cipher_property"},
+                {"$ref": "#/definitions/encryption_mfp_property"},
                 {"$ref": "#/definitions/encryption_wpa_enterprise_base_settings"},
-                {
-                    "properties": {
-                        "eap_type": {
-                            "title": "EAP protocol",
-                            "type": "string",
-                            "enum": ["tls", "ttls"],
-                            "options": {"enum_titles": ["EAP-TLS", "EAP-PEAP"]},
-                            "propertyOrder": 4,
-                        },
-                        "identity": {"type": "string", "propertyOrder": 5},
-                        "password": {"type": "string", "propertyOrder": 6},
-                        "ca_cert": {
-                            "type": "string",
-                            "title": "CA certificate (path)",
-                            "propertyOrder": 7,
-                        },
-                        "client_cert": {
-                            "type": "string",
-                            "title": "client certificate (path)",
-                            "propertyOrder": 8,
-                        },
-                        "priv_key": {
-                            "type": "string",
-                            "title": "private key (path)",
-                            "propertyOrder": 9,
-                        },
-                        "priv_key_pwd": {
-                            "type": "string",
-                            "title": "private key password",
-                            "propertyOrder": 10,
-                        },
-                    }
-                },
+                {"$ref": "#/definitions/encryption_wpa_enterprise_sta_base_settings"},
             ],
         },
         "encryption_wep": {
@@ -732,6 +936,9 @@ schema = {
         "radio_ac_channel_width": {
             "properties": {"channel_width": {"enum": [20, 40, 80, 160]}}
         },
+        "radio_ax_channel_width": {
+            "properties": {"channel_width": {"enum": [20, 40, 80, 160]}}
+        },
         "radio_80211bg_settings": {
             "title": "802.11b/g (2.4 GHz legacy)",
             "allOf": [
@@ -768,15 +975,6 @@ schema = {
                 {"$ref": "#/definitions/radio_n_channel_width"},
             ],
         },
-        "radio_80211ac_2ghz_settings": {
-            "title": "802.11ac (2.4 GHz AC)",
-            "allOf": [
-                {"properties": {"protocol": {"enum": ["802.11ac"]}}},
-                {"$ref": "#/definitions/base_radio_settings"},
-                {"$ref": "#/definitions/radio_2ghz_channels"},
-                {"$ref": "#/definitions/radio_ac_channel_width"},
-            ],
-        },
         "radio_80211ac_5ghz_settings": {
             "title": "802.11ac (5 GHz AC)",
             "allOf": [
@@ -786,6 +984,24 @@ schema = {
                 {"$ref": "#/definitions/radio_ac_channel_width"},
             ],
         },
+        "radio_80211ax_2ghz_settings": {
+            "title": "802.11ax (2.4 GHz AX)",
+            "allOf": [
+                {"properties": {"protocol": {"enum": ["802.11ax"]}}},
+                {"$ref": "#/definitions/base_radio_settings"},
+                {"$ref": "#/definitions/radio_2ghz_channels"},
+                {"$ref": "#/definitions/radio_ax_channel_width"},
+            ],
+        },
+        "radio_80211ax_5ghz_settings": {
+            "title": "802.11ax (5 GHz AX)",
+            "allOf": [
+                {"properties": {"protocol": {"enum": ["802.11ax"]}}},
+                {"$ref": "#/definitions/base_radio_settings"},
+                {"$ref": "#/definitions/radio_5ghz_channels"},
+                {"$ref": "#/definitions/radio_ax_channel_width"},
+            ],
+        },
     },
     "properties": {
         "general": {
@@ -842,8 +1058,9 @@ schema = {
                 "oneOf": [
                     {"$ref": "#/definitions/radio_80211gn_settings"},
                     {"$ref": "#/definitions/radio_80211an_settings"},
-                    {"$ref": "#/definitions/radio_80211ac_2ghz_settings"},
                     {"$ref": "#/definitions/radio_80211ac_5ghz_settings"},
+                    {"$ref": "#/definitions/radio_80211ax_2ghz_settings"},
+                    {"$ref": "#/definitions/radio_80211ax_5ghz_settings"},
                     {"$ref": "#/definitions/radio_80211bg_settings"},
                     {"$ref": "#/definitions/radio_80211a_settings"},
                 ],
@@ -914,6 +1131,7 @@ schema = {
                         "type": "string",
                         "description": "filesystem path",
                         "propertyOrder": 1,
+                        "minLength": 2,
                     },
                     "mode": {
                         "type": "string",
